@@ -4,7 +4,7 @@ from os import mkdir
 from os.path import join
 import pathlib
 from statistics import mean, stdev
-from snprocess.qc.model import plink, read_snp_data, clean, json_save
+from snprocess.qc.model import plink, read_snp_data, json_save
 import snprocess.graph as g
 import pandas as pd
 
@@ -17,7 +17,7 @@ def QC_1(opts):
     inFile: format for input file
     """
 
-    inDir = opts['fileroute'] + opts['inDir']
+    inDir = opts['inDir']
 
     data = {
         "dir": inDir,
@@ -49,13 +49,13 @@ def QC_1(opts):
 
     data = json_save(
         "Histogram individual missingness",
-        outDir + "Hist-individualMissingness.png",
+        "Hist-individualMissingness.png",
         data
     )
 
     data = json_save(
         "Histogram SNP missingness",
-        outDir + "Hist-snpMissingness.png",
+        "Hist-snpMissingness.png",
         data
     )
 
@@ -66,43 +66,43 @@ def QC_1(opts):
     # Also, they filter on SNP missingness and indivudal missingness. Srijan first filters on individual missingness and then on SNPs much later
 
     # filter SNPs at 0.01
-    output, data = plink(" --bfile {} --geno {} --make-bed --out {}plink".format(inFile,
+    output, data = plink(" --bfile {} --geno {} --make-bed --out {}plinka".format(inFile,
                                                                                  opts['geno'], outDir), data)
 
     # filter individuals at 0.05
-    output, data = plink(" --bfile {}plink --mind {} --make-bed --out {}plink".format(outDir,
+    output, data = plink(" --bfile {}plinka --mind {} --make-bed --out {}plinkb".format(outDir,
                                                                                       opts['mind'], outDir), data)
 
     ####################################################
     # STEP 3: sexcheck
     output, data = plink(
-        " --bfile {}plink --check-sex --out {}plink".format(outDir, outDir), data)
+        " --bfile {}plinkb --check-sex --out {}plinka".format(outDir, outDir), data)
 
     # visualize the sex check
-    sc = read_snp_data(outDir, "plink.sexcheck", head=0)
+    sc = read_snp_data(outDir, "plinka.sexcheck", head=0)
     g.sexcheck(sc, outDir)
     # bash("/usr/bin/Rscript --no-save {}sex_check.R {}plink.sexcheck {}".format(outDir, outDir, outDir))
 
     data = json_save(
         "Gender Sexcheck",
-        outDir + "Gender_check.png",
+        "Gender_check.png",
         data
     )
 
     data = json_save(
         "Male Sexcheck",
-        outDir + "Men_check.png",
+        "Men_check.png",
         data
     )
 
     data = json_save(
         "Female Sexcheck",
-        outDir + "Women_check.png",
+        "Women_check.png",
         data
     )
 
     # remove individuals with problematic sex
-    output = read_snp_data(outDir, "plink.sexcheck", head=0)
+    output = read_snp_data(outDir, "plinka.sexcheck", head=0)
     output = output[output['STATUS'] == 'PROBLEM']
     sd_df = pd.DataFrame()
     sd_df[0] = output[output.columns[0]]
@@ -113,7 +113,7 @@ def QC_1(opts):
     # bash('awk \'{{print $1, $2}}\' awkout.txt > {}sex_discrepency.txt'.format(outDir))
 
     output, data = plink(
-        " -bfile {}plink --remove {}sex_discrepency.txt --make-bed --out {}plink".format(outDir, outDir, outDir), data)
+        " -bfile {}plinka --remove {}sex_discrepency.txt --make-bed --out {}plinkb".format(outDir, outDir, outDir), data)
 
     # impute sex... (not sure why this is necessary). NOT RUNNING IT
     # plink -bfile ${outFile}_5 --impute-sex --make-bed --out ${outFile}_6
@@ -123,16 +123,16 @@ def QC_1(opts):
 
     # select autosomal SNPs only, ie from chr 1 to 22
     # bash("awk '{ if ($1 >= 1 && $1 <= 22) print $2 }' plink.bim > {}snp_1_22.txt".format(outDir))
-    output = read_snp_data(outDir, "plink.bim")
+    output = read_snp_data(outDir, "plinkb.bim")
     output = output[1][(output[0] >= 1) & (output[0] <= 22)]
     output.to_csv(sep="\t", path_or_buf='{}snp_1_22.txt'.format(
         outDir), index=False)
 
-    output, data = plink(" --bfile {}plink --extract {}snp_1_22.txt --make-bed --out {}plink".format(outDir, outDir, outDir), data)
+    output, data = plink(" --bfile {}plinkb --extract {}snp_1_22.txt --make-bed --out {}plinka".format(outDir, outDir, outDir), data)
 
     # generate plot of MAF distribution
     output, data = plink(
-        " --bfile {}plink --freq --out {}MAF_check".format(outDir, outDir), data)
+        " --bfile {}plinka --freq --out {}MAF_check".format(outDir, outDir), data)
 
     # visualize it
 
@@ -141,7 +141,7 @@ def QC_1(opts):
 
     data = json_save(
         "MAF Distribution",
-        outDir + "MAF_distribution.png",
+        "MAF_distribution.png",
         data
     )
 
@@ -149,37 +149,36 @@ def QC_1(opts):
 
     # remove SNPs with low MAF... major point of diversion. Srijan's MAF filtering crieria is VERY small. 0.005 vs what they recommend here of 0.05. I'll go midway with 0.01.
     # maf filter at 0.005
-    output, data = plink(" --bfile {}plink --maf {} --make-bed --out {}plink".format(outDir,
+    output, data = plink(" --bfile {}plinka --maf {} --make-bed --out {}plinkb".format(outDir,
                                                                                      opts['maf'], outDir), data)
 
     ####################################################
     # STEP 5: Delete SNPs not in the Hardy-WEinberg equilibrium (HWE)
 
     output, data = plink(
-        " --bfile {}plink --hardy --out {}plink".format(outDir, outDir), data)
+        " --bfile {}plinkb --hardy --out {}plinka".format(outDir, outDir), data)
 
     # select SNPs with HWE p-value below 0.00001
     # bash("awk '{ if ($9 < 0.0001) print $0 }' {}.hwe > {}zoomhwe.hwe".format(outFile, outDir))
-    output = read_snp_data(outDir, "plink.hwe", head=0)
+    output = read_snp_data(outDir, "plinka.hwe", head=0)
     # output = output[output.columns[0]][(output[output.columns[8]] < .0001)]
-    # TODO question about data table
     output = output[(output[output.columns[8]] > opts['hwe'])]
     output.to_csv(sep="\t", path_or_buf='{}zoom.hwe'.format( #zoom is file of snps to remove
         outDir), index=False)
 
-    hwe_df = read_snp_data(outDir, "plink.hwe", head=0)
+    hwe_df = read_snp_data(outDir, "plinka.hwe", head=0)
     zoom = read_snp_data(outDir, "zoom.hwe", head=0)
     g.hwe(hwe_df, zoom, outDir)
 
     data = json_save(
         "Histogram HWE",
-        outDir + "HWE_Histogram.png",
+        "HWE_Histogram.png",
         data
     )
 
     data = json_save(
         "Histogram HWE: strongly deviating SNPs only",
-        outDir + "HWE_below_theshold_Histogram.png",
+        "HWE_below_theshold_Histogram.png",
         data
     )
 
@@ -189,7 +188,7 @@ def QC_1(opts):
     # this is again a departure from Yu's pipeline as they filter at 1e-6
     # plink --bfile ${outFile}_7 --hwe 1e-6 --make-bed --out ${outFile}_8
     output, data = plink(
-        " --bfile {}plink --hwe {} --hwe-all --make-bed --out {}plink".format(outDir, opts['hwe'], outDir), data)
+        " --bfile {}plinka --hwe {} --hwe-all --make-bed --out {}qcplink".format(outDir, opts['hwe'], outDir), data)
 
     ############################################################
     # STEP 6: Heterozygosity and LD Pruning
@@ -203,12 +202,12 @@ def QC_1(opts):
     # Yu's parameters are 100, 25, 0.5. Given the small sample sizes we are dealing with, Yu's parameters, particularly for r^2
     # make more sense. More SNPs would be excluded with r^2=0.2
 
-    output, data = plink(" --bfile {}plink --indep-pairwise {} {} {} --out {}indepSNP".format(outDir,
+    output, data = plink(" --bfile {}qcplink --indep-pairwise {} {} {} --out {}indepSNP".format(outDir,
                                                                                               opts['indep_pairwise'][0], opts['indep_pairwise'][1], opts['indep_pairwise'][2], outDir), data)
 
     # get the pruned data set
     output, data = plink(
-        " --bfile {}plink --extract {}indepSNP.prune.in --het --out {}R_hetCheck".format(outDir, outDir, outDir), data)
+        " --bfile {}qcplink --extract {}indepSNP.prune.in --het --out {}R_hetCheck".format(outDir, outDir, outDir), data)
 
     # plot the heterogygosity rate
     df = read_snp_data(outDir, "R_hetCheck.het", head=0)
@@ -216,7 +215,7 @@ def QC_1(opts):
 
     data = json_save(
         "Heterozygosity Rate",
-        outDir + "heterozygosity.png",
+        "heterozygosity.png",
         data
     )
 
@@ -227,6 +226,7 @@ def QC_1(opts):
 
     df["HET_RATE"] = (df['N(NM)'] - df['O(HOM)']) / df['N(NM)']
 
+    # TODO: fix errors here
     het_fail: pd.DataFrame
     het_fail = df[df['HET_RATE'] < mean(
         df['HET_RATE']) - 3 * stdev(df['HET_RATE'])]
@@ -238,7 +238,6 @@ def QC_1(opts):
     # bash("/usr/bin/Rscript --no-save heterozygosity_outliers.R {}R_hetCheck {}".format(outDir, outDir))
 
     # need to exclude these individuals from the analysis.
-    # TODO
     # bash('''sed 's/"// g' {}fail-het-qc.txt | awk '{print $1, $2}' > {}het-fail-ind.txt'''.format(outDir, outDir))
 
     # plink(" --bfile plink --remove {}het-fail-ind.txt --make-bed".format(outDir))
@@ -248,7 +247,7 @@ def QC_1(opts):
 
     # This step isn't there in Yu's workflow, because it shouldn't really be necessary.
     # relatedness @0.2
-    output, data = plink(" --bfile {}plink --extract {}indepSNP.prune.in --genome --min {} --out {}pihat_min0.2".format(
+    output, data = plink(" --bfile {}qcplink --extract {}indepSNP.prune.in --genome --min {} --out {}pihat_min0.2".format(
         outDir, outDir, opts['relatedness'], outDir), data)
 
     # visualize relations. But there will be none! or should be none!
@@ -258,7 +257,6 @@ def QC_1(opts):
     output.to_csv(sep="\t", path_or_buf='{}zoom_pihat.genome'.format(
         outDir), index=False)
 
-    # TODO
     # bash("/usr/bin/Rscript --no-save relatedness.R {}pihat_min0.2.genome {}zoom_pihat.genome {}".format(outDir, outDir, outDir))
 
     
